@@ -3,6 +3,9 @@ rm(
   assess_source_good,
   pkg_ref_source_bad,
   assess_source_bad,
+  pkg_ref_source_bad2,
+  assess_source_bad2,
+  score_source_bad2,
   pkg_ref_stdlib_install,
   assess_stdlib_install,
   pkg_ref_stdlibs_install,
